==> swagger-typescript-api-3.1.2.tgz: package/index.js <==
#!/usr/bin/env node

// Copyright (c) 2019-present acacode
// Node module: swagger-typescript-api
// This file is licensed under the MIT License.
// License text available at https://opensource.org/licenses/MIT
// Repository https://github.com/acacode/swagger-typescript-api

const program = require("commander");
const { resolve } = require("path");
const { generateApi } = require("./src");
const { version } = require("./package.json");

program
  .version(version, "-v, --version", "output the current version")
  .description("Generate api via swagger scheme.\nSupports OA 3.0, 2.0, JSON, yaml.")
  .requiredOption("-p, --path <path>", "path/url to swagger scheme")
  .option("-o, --output <output>", "output path of typescript api file", "./")
  .option("-n, --name <name>", "name of output typescript api file", "Api.ts")
  .option("-t, --templates <path>", "path to folder containing templates")
  .option(
    "-d, --default-as-success",
    'use "default" response status code as success response too.\n' +
      'some swagger schemas use "default" response status code as success response type by default.',
    false,
  )
  .option(
    "-r, --responses",
    "generate additional information about request responses\n" +
      "also add typings for bad responses",
    false,
  )
  .option("--union-enums", 'generate all "enum" types as union types (T1 | T2 | TN)', false)
  .option("--route-types", "generate type definitions for API routes", false)
  .option("--no-client", "do not generate an API class", false)
  .option("--js", "generate js api module with declaration file", false)
  .option(
    "--module-name-index <number>",
    "determines which path index should be used for routes separation (example: GET:/fruites/getFruit -> index:0 -> moduleName -> fruites)",
    0,
  );

program.parse(process.argv);

const {
  path,
  output,
  name,
  templates,
  unionEnums,
  routeTypes,
  client,
  defaultAsSuccess,
  responses,
  js,
  moduleNameIndex,
} = program;

generateApi({
  name,
  url: path,
  generateRouteTypes: routeTypes,
  generateClient: client,
  defaultResponseAsSuccess: defaultAsSuccess,
  generateUnionEnums: unionEnums,
  generateResponses: responses,
  input: resolve(process.cwd(), path),
  output: resolve(process.cwd(), output || "."),
  templates: resolve(
    templates ? process.cwd() : __dirname,
    templates || "./src/templates/defaults",
  ),
  toJS: !!js,
  moduleNameIndex: +(moduleNameIndex || 0),
});

==> swagger-typescript-api-4.0.0.tgz: package/index.js <==
#!/usr/bin/env node

// Copyright (c) 2019-present acacode
// Node module: swagger-typescript-api
// This file is licensed under the MIT License.
// License text available at https://opensource.org/licenses/MIT
// Repository https://github.com/acacode/swagger-typescript-api

const { Command } = require("commander");
const { resolve } = require("path");
const { generateApi } = require("./src");
const { version, name: packageName } = require("./package.json");

const program = new Command(packageName);

program.storeOptionsAsProperties(true);

program
  .version(version, "-v, --version", "output the current version")
  .description("Generate api via swagger scheme.\nSupports OA 3.0, 2.0, JSON, yaml.");

program
  .requiredOption("-p, --path <path>", "path/url to swagger scheme")
  .option("-o, --output <output>", "output path of typescript api file", "./")
  .option("-n, --name <name>", "name of output typescript api file", "Api.ts")
  .option("-t, --templates <path>", "path to folder containing templates")
  .option(
    "-d, --default-as-success",
    'use "default" response status code as success response too.\n' +
      'some swagger schemas use "default" response status code as success response type by default.',
    false,
  )
  .option(
    "-r, --responses",
    "generate additional information about request responses\n" +
      "also add typings for bad responses",
    false,
  )
  .option("--union-enums", 'generate all "enum" types as union types (T1 | T2 | TN)', false)
  .option("--route-types", "generate type definitions for API routes", false)
  .option("--no-client", "do not generate an API class", false)
  .option(
    "--enum-names-as-values",
    "use values in 'x-enumNames' as enum values (not only as keys)",
    false,
  )
  .option(
    "--extract-request-params",
    "extract request params to data contract (Also combine path params and query params into one object)",
    false,
  )
  .option(
    "--modular",
    "generate separated files for http client, data contracts, and routes",
    false,
  )
  .option("--js", "generate js api module with declaration file", false)
  .option(
    "--module-name-index <number>",
    "determines which path index should be used for routes separation (example: GET:/fruites/getFruit -> index:0 -> moduleName -> fruites)",
    0,
  );

program.parse(process.argv);

const {
  path,
  output,
  name,
  templates,
  unionEnums,
  routeTypes,
  client,
  defaultAsSuccess,
  responses,
  modular,
  js,
  moduleNameIndex,
  extractRequestParams,
  enumNamesAsValues,
} = program;

generateApi({
  name,
  url: path,
  generateRouteTypes: routeTypes,
  generateClient: client,
  defaultResponseAsSuccess: defaultAsSuccess,
  generateUnionEnums: unionEnums,
  generateResponses: responses,
  extractRequestParams: extractRequestParams,
  input: resolve(process.cwd(), path),
  output: resolve(process.cwd(), output || "."),
  templates,
  modular: !!modular,
  toJS: !!js,
  enumNamesAsValues: enumNamesAsValues,
  moduleNameIndex: +(moduleNameIndex || 0),
});
